@@ -1000,11 +1000,486 @@ magui_magnification_options_save_changed (void)
     magconf_save_zoomer_in_schema (DEFAULT_MAGNIFIER_SCHEMA, magnifier_setting);
 }
 #endif
+
+static gboolean
+magui_check_for_valid_screen (const gchar *new_val)
+{
+    GdkDisplay *disp = NULL;
+		
+    if (!new_val)
+		return FALSE;
+    
+    disp = gdk_display_open (new_val);
+    if (disp)
+    {
+	/*gdk_display_close (disp); waiting for bug #85715*/
+	return TRUE;
+    }
+    return FALSE;
+}
+
+static void 
+magui_set_source_screen ()
+{
+    const gchar *sval = 
+	gtk_entry_get_text ( GTK_ENTRY (et_source));
+		
+    if (magui_check_for_valid_screen (sval))
+    {
+        g_free (magnifier_setting->source);
+        magnifier_setting->source = g_strdup (sval);
+
+        magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+ 				     GCONF_VALUE_STRING,
+				     MAGNIFIER_SOURCE,
+				     (gpointer)magnifier_setting->source);
+    }
+    else	
+    {
+    	gdk_beep ();
+    	gtk_entry_set_text (GTK_ENTRY (et_source), 
+			    g_strdup (magnifier_setting->source));
+    }
+}
+
+static void
+magui_set_target_screen ()
+{
+    const gchar *sval = 
+	gtk_entry_get_text ( GTK_ENTRY (et_target));
+	
+    if (magui_check_for_valid_screen (sval))
+    {
+	g_free (magnifier_setting->target);
+	magnifier_setting->target = g_strdup (sval);
+	
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				     GCONF_VALUE_STRING,
+				     MAGNIFIER_TARGET,
+				     (gpointer)magnifier_setting->target);
+    }
+    else	
+    {
+	gdk_beep ();
+    	gtk_entry_set_text (GTK_ENTRY (et_target), 
+    			    g_strdup (magnifier_setting->source));
+    }
+}	
+
+static void
+magui_set_border_color_value ()
+{
+    guint8 r8,g8,b8,a8;
+    guint ret_color = 0;
+    gnome_color_picker_get_i8   (GNOME_COLOR_PICKER (cp_border_color), 
+				    &r8, &g8, &b8, &a8);
+
+    ret_color = 0xff - a8;
+    ret_color = (ret_color << 8) + r8;
+    ret_color = (ret_color << 8) + g8;
+    ret_color = (ret_color << 8) + b8;
+    
+    if (magnifier_setting->border_color != ret_color)
+    {
+	magnifier_setting->border_color = ret_color;
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_INT,
+				    MAGNIFIER_BORDER_COLOR,
+				    (gpointer)&magnifier_setting->border_color);
+    }
+}
+
+static void
+magui_set_border_size_value ()
+{
+    gint ival = 
+	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_border_size));
+    if (magnifier_setting->border_width != ival)
+    {
+	magnifier_setting->border_width = ival;
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_INT,
+				    MAGNIFIER_BORDER_WIDTH,
+				    (gpointer)&magnifier_setting->border_width);    
+    }
+}	
+
+static void
+magui_set_zp_left_value ()
+{
+    gint ival = 
+	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_zp_left));
+    if ((magnifier_setting->zp).left != ival)
+    {
+	(magnifier_setting->zp).left = ival;
+        gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_width),
+		(magnifier_setting->zp).left, display_size.size_x);
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_INT,
+				    MAGNIFIER_ZP_LEFT,
+				    (gpointer)&(magnifier_setting->zp).left);    
+    }
+}	
+
+static void
+magui_set_zp_top_value ()
+{
+    gint ival = 
+	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_zp_top));
+    if ((magnifier_setting->zp).top != ival)
+    {
+	(magnifier_setting->zp).top = ival;
+	gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_height),
+		(magnifier_setting->zp).top, display_size.size_y);
+
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_INT,
+				    MAGNIFIER_ZP_TOP,
+				    (gpointer)&(magnifier_setting->zp).top);    
+    }
+}	
+
+static void
+magui_set_zp_height_value ()
+{
+    gint ival = 
+	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_zp_height));
+    if ((magnifier_setting->zp).height != ival)
+    {
+	(magnifier_setting->zp).height = ival;
+        gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_top),
+		 DEFAULT_SCREEN_MIN_SIZE,(magnifier_setting->zp).height);
+
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_INT,
+				    MAGNIFIER_ZP_HEIGHT,
+				    (gpointer)&(magnifier_setting->zp).height);    
+    }
+}	
+
+static void
+magui_set_zp_width_value ()
+{
+    gint ival = 
+	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_zp_width));
+
+    if ((magnifier_setting->zp).width != ival)
+    {
+	(magnifier_setting->zp).width = ival;
+	gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_left),
+		 DEFAULT_SCREEN_MIN_SIZE,(magnifier_setting->zp).width);
+
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_INT,
+				    MAGNIFIER_ZP_WIDTH,
+				    (gpointer)&(magnifier_setting->zp).width);    
+    }
+}	
+
+static void
+magui_set_mouse_tracking_mode ()
+{
+    gchar *tmp = NULL;
+    gint iter;
+    tmp = (gchar*)gtk_entry_get_text (GTK_ENTRY 
+				     (GTK_COMBO 
+				     (cb_mouse_tracking)->entry)
+				     );
+				     
+    if (!tmp || strlen (tmp) == 0)
+	return;
+	
+    for (iter = 0; iter < G_N_ELEMENTS (magui_mouse_tracking); iter++)
+    {
+	if (strcmp (_(magui_mouse_tracking[iter].description), tmp) == 0)
+	{
+	    if (strcmp (magui_mouse_tracking[iter].key,
+			magnifier_setting->mouse_tracking))
+	    {
+		    g_free (magnifier_setting->mouse_tracking);
+		    magnifier_setting->mouse_tracking = 
+			g_strdup (magui_mouse_tracking[iter].key);
+		    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+						GCONF_VALUE_STRING,
+						MAGNIFIER_MOUSE_TRACKING,
+						(gpointer)magnifier_setting->mouse_tracking);
+
+		    break;
+	    }
+	}
+    }	 
+
+}
+
+static void
+magui_set_smoothing_value ()
+{
+    gchar *tmp = NULL;
+    gint iter;
+    tmp = (gchar*)gtk_entry_get_text (GTK_ENTRY 
+				     (GTK_COMBO 
+				     (cb_smoothing)->entry
+				     ));
+
+    if (tmp)
+    {
+	for (iter = 0; iter < G_N_ELEMENTS (magui_smoothing); iter++)
+	{
+	    if (strcmp (_(magui_smoothing[iter].description), tmp) == 0)
+	    {	
+		if (magui_smoothing[iter].key != magnifier_setting->smoothing)
+		{
+		    g_free (magnifier_setting->smoothing);
+		    magnifier_setting->smoothing = 
+			g_strdup (magui_smoothing[iter].key);
+		    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+					    GCONF_VALUE_STRING,
+					    MAGNIFIER_SMOOTHING,
+					    (gpointer)magnifier_setting->smoothing);
+		
+		    break;
+		}
+	    }
+	}
+    }	 
+
+}
+
+static void
+magui_set_invert_on_off ()
+{
+    gboolean bval = 
+	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ck_invert));
+    if (magnifier_setting->invert != bval)
+    {
+	magnifier_setting->invert = bval;
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_BOOL,
+				    MAGNIFIER_INVERT,
+				    (gpointer)&magnifier_setting->invert);
+    }
+}
+
+
+static void
+magui_set_panning_on_off ()
+{
+    gboolean bval = 
+	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ck_panning));
+    if (magnifier_setting->panning != bval)
+    {
+	magnifier_setting->panning = bval;
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_BOOL,
+				    MAGNIFIER_PANNING,
+				    (gpointer)&magnifier_setting->panning);
+    }
+}
+
+
+static void
+magui_set_zoomfactor_x_value ()
+{
+
+    gdouble dval =
+	gtk_spin_button_get_value (GTK_SPIN_BUTTON (sp_factorx));
+	
+    if (dval == magnifier_setting->zoomfactorx) 
+	return;
+
+    if (magnifier_setting->zoomfactor_lock)
+    {
+	magnifier_setting->zoomfactorx = dval;
+	    		
+	magnifier_setting->zoomfactory = 
+	    magnifier_setting->zoomfactorx ;
+
+	gtk_spin_button_set_value ( GTK_SPIN_BUTTON (sp_factory), 
+				magnifier_setting->zoomfactory);		
+	
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_FLOAT,
+				    MAGNIFIER_ZOOM_FACTOR_Y,
+				    (gpointer)&magnifier_setting->zoomfactory);
+	
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_FLOAT,
+				    MAGNIFIER_ZOOM_FACTOR_X,
+				    (gpointer)&magnifier_setting->zoomfactorx);
+    }
+    else
+    {
+	magnifier_setting->zoomfactorx = dval;
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_FLOAT,
+				    MAGNIFIER_ZOOM_FACTOR_X,
+				    (gpointer)&magnifier_setting->zoomfactorx);
+    }
+}
+
+static void
+magui_set_zoomfactor_y_value ()
+{
+    gdouble dval =
+	gtk_spin_button_get_value (GTK_SPIN_BUTTON (sp_factory));
+	
+    if (dval == magnifier_setting->zoomfactory) 
+	return;
+    
+    if (magnifier_setting->zoomfactor_lock)
+    {
+	magnifier_setting->zoomfactorx = dval;
+		
+	magnifier_setting->zoomfactory = 
+	    magnifier_setting->zoomfactorx ;
+		
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (sp_factorx), 
+		magnifier_setting->zoomfactorx);		
+	
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_FLOAT,
+				    MAGNIFIER_ZOOM_FACTOR_Y,
+				    (gpointer)&magnifier_setting->zoomfactory);
+	
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_FLOAT,
+				    MAGNIFIER_ZOOM_FACTOR_X,
+				    (gpointer)&magnifier_setting->zoomfactorx);
+    }
+    else
+    {
+	magnifier_setting->zoomfactory = dval;
+	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				    GCONF_VALUE_FLOAT,
+				    MAGNIFIER_ZOOM_FACTOR_Y,
+				    (gpointer)&magnifier_setting->zoomfactory);
+
+    }
+}
+
+static void
+magui_set_zoomfactor_lock_on_off ()
+{
+    gboolean bval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ck_lock_factor));     
+    
+    if (magnifier_setting->zoomfactor_lock == bval) 
+    	return;
+    
+    magnifier_setting->zoomfactor_lock = bval;
+	
+    magconf_zoomfactor_lock_set (magnifier_setting->zoomfactor_lock);
+    
+    if (magnifier_setting->zoomfactor_lock)
+    {
+	magnifier_setting->zoomfactorx = 
+	magnifier_setting->zoomfactory = (  magnifier_setting->zoomfactory + 
+					    magnifier_setting->zoomfactorx) / 2.0;
+    				
+	gtk_spin_button_set_value   (GTK_SPIN_BUTTON (sp_factorx), 
+				     magnifier_setting->zoomfactorx);
+
+        gtk_spin_button_set_value   (GTK_SPIN_BUTTON (sp_factory), 
+    				     magnifier_setting->zoomfactory);				
+
+        magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				     GCONF_VALUE_FLOAT,
+				     MAGNIFIER_ZOOM_FACTOR_Y,
+				     (gpointer)&magnifier_setting->zoomfactory);
+	
+        magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				     GCONF_VALUE_FLOAT,
+				     MAGNIFIER_ZOOM_FACTOR_X,
+				     (gpointer)&magnifier_setting->zoomfactorx);
+    }
+
+    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				GCONF_VALUE_BOOL,
+				MAGNIFIER_ZOOM_FACTOR_LOCK,
+				(gpointer)&magnifier_setting->zoomfactor_lock);
+	
+}
+
+static void
+magui_set_focus_tracking_mode ()
+{
+    g_free (magnifier_setting->alignment_x);
+    g_free (magnifier_setting->alignment_y);
+    
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rb_focus_tracking[MAG_FOCUS_TRACKING_NONE])))
+    {
+    	magnifier_setting->alignment_x = g_strdup (MAGUI_ALIGNMENT_NONE);
+	magnifier_setting->alignment_y = g_strdup (MAGUI_ALIGNMENT_NONE);
+    }
+    else
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rb_focus_tracking[MAG_FOCUS_TRACKING_CENTERED])))
+    {
+	magnifier_setting->alignment_x = g_strdup (MAGUI_ALIGNMENT_CENTERED);
+	magnifier_setting->alignment_y = g_strdup (MAGUI_ALIGNMENT_CENTERED);
+    }
+    else
+    {
+    	magnifier_setting->alignment_x = g_strdup (MAGUI_ALIGNMENT_AUTO);
+	magnifier_setting->alignment_y = g_strdup (MAGUI_ALIGNMENT_AUTO);
+    }
+    
+    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				 GCONF_VALUE_STRING,
+				 MAGNIFIER_ALIGNMENT_X,
+				(gpointer)magnifier_setting->alignment_x);				
+    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
+				 GCONF_VALUE_STRING,
+				 MAGNIFIER_ALIGNMENT_Y,
+				(gpointer)magnifier_setting->alignment_x);				
+}
+
+
 void
 magui_magnification_options_response (GtkDialog *dialog,
 				      gint       response_id,
 				      gpointer   user_data)
 {
+    if (response_id == GTK_RESPONSE_APPLY)
+    {
+    	magui_set_source_screen ();
+	magui_set_target_screen ();
+	magui_set_zoomfactor_lock_on_off ();
+	magui_set_zoomfactor_x_value ();
+	magui_set_zoomfactor_y_value ();
+	magui_set_border_size_value ();
+	magui_set_border_color_value ();
+	magui_set_zp_left_value ();
+	magui_set_zp_top_value ();
+	magui_set_zp_width_value ();
+	magui_set_zp_height_value ();
+	magui_set_smoothing_value ();
+	magui_set_mouse_tracking_mode ();
+	magui_set_focus_tracking_mode ();
+	magui_set_panning_on_off ();
+	magui_set_invert_on_off ();
+	return;
+    } 
+    else
+    if (response_id == GTK_RESPONSE_OK)
+    {
+	magui_set_source_screen ();
+	magui_set_target_screen ();
+	magui_set_border_size_value ();
+	magui_set_border_color_value ();
+	magui_set_zp_left_value ();
+	magui_set_zp_top_value ();
+	magui_set_zp_width_value ();
+	magui_set_zp_height_value ();
+	magui_set_zoomfactor_lock_on_off ();
+	magui_set_zoomfactor_x_value ();
+	magui_set_zoomfactor_y_value ();
+	magui_set_smoothing_value ();
+	magui_set_mouse_tracking_mode ();
+	magui_set_focus_tracking_mode ();
+	magui_set_panning_on_off ();
+	magui_set_invert_on_off ();
+
+    }
+    else
     if (response_id == GTK_RESPONSE_CLOSE) 
     {
         if (mag_setting_clone_opt)
@@ -1049,421 +1524,7 @@ magui_magnification_options_remove  (GtkButton       *button,
 }
 
 
-void
-magui_color_border_color_set (GtkWidget *w,
-			    guint r,
-			    guint g,
-			    guint b, 
-			    guint a,
-			    gpointer data)
-{
-    guint8 r8,g8,b8,a8;
-    guint ret_color = 0;
-    gnome_color_picker_get_i8   (GNOME_COLOR_PICKER (cp_border_color), 
-				    &r8, &g8, &b8, &a8);
 
-    ret_color = 0xff - a8;
-    ret_color = (ret_color << 8) + r8;
-    ret_color = (ret_color << 8) + g8;
-    ret_color = (ret_color << 8) + b8;
-    
-    if (magnifier_setting->border_color != ret_color)
-    {
-	magnifier_setting->border_color = ret_color;
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
-				    MAGNIFIER_BORDER_COLOR,
-				    (gpointer)&magnifier_setting->border_color);
-    }
-}
-
-void
-magui_border_size_value_changed (GtkWidget *widget,
-				gpointer user_data)
-{
-    gint ival = 
-	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_border_size));
-    if (magnifier_setting->border_width != ival)
-    {
-	magnifier_setting->border_width = ival;
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
-				    MAGNIFIER_BORDER_WIDTH,
-				    (gpointer)&magnifier_setting->border_width);    
-    }
-}	
-
-void
-magui_zp_left_value_changed (GtkWidget *widget,
-			    gpointer user_data)
-{
-    gint ival = 
-	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_zp_left));
-    if ((magnifier_setting->zp).left != ival)
-    {
-	(magnifier_setting->zp).left = ival;
-        gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_width),
-		(magnifier_setting->zp).left, display_size.size_x);
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
-				    MAGNIFIER_ZP_LEFT,
-				    (gpointer)&(magnifier_setting->zp).left);    
-    }
-}	
-
-void
-magui_zp_top_value_changed (GtkWidget *widget,
-			    gpointer user_data)
-{
-    gint ival = 
-	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_zp_top));
-    if ((magnifier_setting->zp).top != ival)
-    {
-	(magnifier_setting->zp).top = ival;
-	gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_height),
-		(magnifier_setting->zp).top, display_size.size_y);
-
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
-				    MAGNIFIER_ZP_TOP,
-				    (gpointer)&(magnifier_setting->zp).top);    
-    }
-}	
-
-void
-magui_zp_height_value_changed (GtkWidget *widget,
-			       gpointer user_data)
-{
-    gint ival = 
-	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_zp_height));
-    if ((magnifier_setting->zp).height != ival)
-    {
-	(magnifier_setting->zp).height = ival;
-        gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_top),
-		 DEFAULT_SCREEN_MIN_SIZE,(magnifier_setting->zp).height);
-
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
-				    MAGNIFIER_ZP_HEIGHT,
-				    (gpointer)&(magnifier_setting->zp).height);    
-    }
-}	
-
-void
-magui_zp_width_value_changed (GtkWidget *widget,
-			      gpointer user_data)
-{
-    gint ival = 
-	gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sp_zp_width));
-
-    if ((magnifier_setting->zp).width != ival)
-    {
-	(magnifier_setting->zp).width = ival;
-	gtk_spin_button_set_range ( GTK_SPIN_BUTTON (sp_zp_left),
-		 DEFAULT_SCREEN_MIN_SIZE,(magnifier_setting->zp).width);
-
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_INT,
-				    MAGNIFIER_ZP_WIDTH,
-				    (gpointer)&(magnifier_setting->zp).width);    
-    }
-}	
-
-void
-magui_source_changed (GtkWidget *widget,
-			    gpointer user_data)
-{
-    const gchar *sval = 
-	gtk_entry_get_text ( GTK_ENTRY (et_source));
-	
-    g_free (magnifier_setting->source);
-	    	    
-    magnifier_setting->source = g_strdup (sval);
-	
-    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				GCONF_VALUE_STRING,
-				MAGNIFIER_SOURCE,
-				(gpointer)magnifier_setting->source);    
-}	
-
-void
-magui_target_changed (GtkWidget *widget,
-		      gpointer user_data)
-{
-    const gchar *sval = 
-	gtk_entry_get_text ( GTK_ENTRY (et_target));
-	
-    g_free (magnifier_setting->target);
-	    
-    magnifier_setting->target = g_strdup (sval);
-	
-    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				GCONF_VALUE_STRING,
-				MAGNIFIER_TARGET,
-				(gpointer)magnifier_setting->target);    
-}	
-
-void
-magui_mouse_tracking_value_changed(GtkWidget *widget,
-				  gpointer data)
-{
-    gchar *tmp = NULL;
-    gint iter;
-    tmp = (gchar*)gtk_entry_get_text (GTK_ENTRY 
-				     (GTK_COMBO 
-				     (cb_mouse_tracking)->entry)
-				     );
-				     
-    if (!tmp || strlen (tmp) == 0)
-	return;
-	
-    for (iter = 0; iter < G_N_ELEMENTS (magui_mouse_tracking); iter++)
-    {
-	if (strcmp (_(magui_mouse_tracking[iter].description), tmp) == 0)
-	{
-	    if (strcmp (magui_mouse_tracking[iter].key,
-			magnifier_setting->mouse_tracking))
-	    {
-		    g_free (magnifier_setting->mouse_tracking);
-		    magnifier_setting->mouse_tracking = 
-			g_strdup (magui_mouse_tracking[iter].key);
-		    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-						GCONF_VALUE_STRING,
-						MAGNIFIER_MOUSE_TRACKING,
-						(gpointer)magnifier_setting->mouse_tracking);
-
-		    break;
-	    }
-	}
-    }	 
-
-}
-
-void
-magui_smoothing_value_changed(GtkWidget *widget,
-			    gpointer data)
-{
-    gchar *tmp = NULL;
-    gint iter;
-    tmp = (gchar*)gtk_entry_get_text (GTK_ENTRY 
-				     (GTK_COMBO 
-				     (cb_smoothing)->entry
-				     ));
-
-    if (tmp)
-    {
-	for (iter = 0; iter < G_N_ELEMENTS (magui_smoothing); iter++)
-	{
-	    if (strcmp (_(magui_smoothing[iter].description), tmp) == 0)
-	    {	
-		if (magui_smoothing[iter].key != magnifier_setting->smoothing)
-		{
-		    g_free (magnifier_setting->smoothing);
-		    magnifier_setting->smoothing = 
-			g_strdup (magui_smoothing[iter].key);
-		    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-					    GCONF_VALUE_STRING,
-					    MAGNIFIER_SMOOTHING,
-					    (gpointer)magnifier_setting->smoothing);
-		
-		    break;
-		}
-	    }
-	}
-    }	 
-
-}
-
-void
-magui_invert_toggled(GtkWidget *widget,
-		    gpointer data)
-{
-    gboolean bval = 
-	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ck_invert));
-    if (magnifier_setting->invert != bval)
-    {
-	magnifier_setting->invert = bval;
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_BOOL,
-				    MAGNIFIER_INVERT,
-				    (gpointer)&magnifier_setting->invert);
-    }
-}
-
-
-void
-magui_panning_toggled(GtkWidget *widget,
-		    gpointer data)
-{
-    gboolean bval = 
-	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ck_panning));
-    if (magnifier_setting->panning != bval)
-    {
-	magnifier_setting->panning = bval;
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_BOOL,
-				    MAGNIFIER_PANNING,
-				    (gpointer)&magnifier_setting->panning);
-    }
-}
-
-
-void
-on_change_sp1_value	(GtkWidget       *widget,
-        	        gpointer         user_data)
-{
-
-    gdouble dval =
-	gtk_spin_button_get_value (GTK_SPIN_BUTTON (sp_factorx));
-	
-    if (dval == magnifier_setting->zoomfactorx) 
-	return;
-
-    if (magnifier_setting->zoomfactor_lock)
-    {
-	magnifier_setting->zoomfactorx = dval;
-	    		
-	magnifier_setting->zoomfactory = 
-	    magnifier_setting->zoomfactorx ;
-
-	gtk_spin_button_set_value ( GTK_SPIN_BUTTON (sp_factory), 
-				magnifier_setting->zoomfactory);		
-	
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_FLOAT,
-				    MAGNIFIER_ZOOM_FACTOR_Y,
-				    (gpointer)&magnifier_setting->zoomfactory);
-	
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_FLOAT,
-				    MAGNIFIER_ZOOM_FACTOR_X,
-				    (gpointer)&magnifier_setting->zoomfactorx);
-    }
-    else
-    {
-	magnifier_setting->zoomfactorx = dval;
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_FLOAT,
-				    MAGNIFIER_ZOOM_FACTOR_X,
-				    (gpointer)&magnifier_setting->zoomfactorx);
-    }
-}
-
-void
-on_change_sp2_value	(GtkWidget       *widget,
-        	        gpointer         user_data)
-{
-    gdouble dval =
-	gtk_spin_button_get_value (GTK_SPIN_BUTTON (sp_factory));
-	
-    if (dval == magnifier_setting->zoomfactory) 
-	return;
-    
-    if (magnifier_setting->zoomfactor_lock)
-    {
-	magnifier_setting->zoomfactorx = dval;
-		
-	magnifier_setting->zoomfactory = 
-	    magnifier_setting->zoomfactorx ;
-		
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (sp_factorx), 
-		magnifier_setting->zoomfactorx);		
-	
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_FLOAT,
-				    MAGNIFIER_ZOOM_FACTOR_Y,
-				    (gpointer)&magnifier_setting->zoomfactory);
-	
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_FLOAT,
-				    MAGNIFIER_ZOOM_FACTOR_X,
-				    (gpointer)&magnifier_setting->zoomfactorx);
-    }
-    else
-    {
-	magnifier_setting->zoomfactory = dval;
-	magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				    GCONF_VALUE_FLOAT,
-				    MAGNIFIER_ZOOM_FACTOR_Y,
-				    (gpointer)&magnifier_setting->zoomfactory);
-
-    }
-}
-
-void
-magui_change_lock_factor(GtkWidget       *widget,
-    	        	gpointer         user_data)
-{
-    gboolean bval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ck_lock_factor));     
-    
-    if (magnifier_setting->zoomfactor_lock == bval) 
-	return;
-    
-    magnifier_setting->zoomfactor_lock = bval;
-	
-    magconf_zoomfactor_lock_set (magnifier_setting->zoomfactor_lock);
-    
-    magnifier_setting->zoomfactorx = 
-	magnifier_setting->zoomfactory = (  magnifier_setting->zoomfactory + 
-					    magnifier_setting->zoomfactorx) / 2.0;
-				
-    gtk_spin_button_set_value   (GTK_SPIN_BUTTON (sp_factorx), 
-				magnifier_setting->zoomfactorx);
-
-    gtk_spin_button_set_value 	(GTK_SPIN_BUTTON (sp_factory), 
-				magnifier_setting->zoomfactory);				
-
-    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				GCONF_VALUE_BOOL,
-				MAGNIFIER_ZOOM_FACTOR_LOCK,
-				(gpointer)&magnifier_setting->zoomfactor_lock);
-	
-    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				GCONF_VALUE_FLOAT,
-				MAGNIFIER_ZOOM_FACTOR_Y,
-				(gpointer)&magnifier_setting->zoomfactory);
-	
-    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				GCONF_VALUE_FLOAT,
-				MAGNIFIER_ZOOM_FACTOR_X,
-				(gpointer)&magnifier_setting->zoomfactorx);				
-}
-
-static void
-magui_rb_focus_tracking_toggled (GtkWidget	*widget,
-				gpointer 	user_data)
-{
-    g_free (magnifier_setting->alignment_x);
-    g_free (magnifier_setting->alignment_y);
-    
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rb_focus_tracking[MAG_FOCUS_TRACKING_NONE])))
-    {
-    	magnifier_setting->alignment_x = g_strdup (MAGUI_ALIGNMENT_NONE);
-	magnifier_setting->alignment_y = g_strdup (MAGUI_ALIGNMENT_NONE);
-    }
-    else
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rb_focus_tracking[MAG_FOCUS_TRACKING_CENTERED])))
-    {
-	magnifier_setting->alignment_x = g_strdup (MAGUI_ALIGNMENT_CENTERED);
-	magnifier_setting->alignment_y = g_strdup (MAGUI_ALIGNMENT_CENTERED);
-    }
-    else
-    {
-    	magnifier_setting->alignment_x = g_strdup (MAGUI_ALIGNMENT_AUTO);
-	magnifier_setting->alignment_y = g_strdup (MAGUI_ALIGNMENT_AUTO);
-    }
-    
-    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				 GCONF_VALUE_STRING,
-				 MAGNIFIER_ALIGNMENT_X,
-				(gpointer)magnifier_setting->alignment_x);				
-    magconf_save_item_in_schema (DEFAULT_MAGNIFIER_SCHEMA,
-				 GCONF_VALUE_STRING,
-				 MAGNIFIER_ALIGNMENT_Y,
-				(gpointer)magnifier_setting->alignment_x);				
-}
-
-			
 void
 magui_set_handlers_magnification_options(GladeXML *xml)
 {    
@@ -1505,13 +1566,7 @@ magui_set_handlers_magnification_options(GladeXML *xml)
     gtk_entry_set_editable (GTK_ENTRY (GTK_COMBO (cb_smoothing)->entry), FALSE);
     gtk_entry_set_editable (GTK_ENTRY (GTK_COMBO (cb_mouse_tracking)->entry), FALSE);
     
-    glade_xml_signal_connect (xml, "on_et_source_activate",		
-			    GTK_SIGNAL_FUNC (magui_source_changed));
-
-    glade_xml_signal_connect (xml, "on_et_target_activate",		
-			    GTK_SIGNAL_FUNC (magui_target_changed));
-
-
+    
     g_signal_connect (w_magnification_options, "response",
 		      G_CALLBACK (magui_magnification_options_response), NULL);
     g_signal_connect (w_magnification_options, "delete_event",
@@ -1519,45 +1574,6 @@ magui_set_handlers_magnification_options(GladeXML *xml)
 
     glade_xml_signal_connect (xml, "on_w_mag_option_remove",		
 			    GTK_SIGNAL_FUNC (magui_magnification_options_remove));
-    glade_xml_signal_connect(xml,"on_color_border_color_set",		
-			    GTK_SIGNAL_FUNC(magui_color_border_color_set));
-			    
-    glade_xml_signal_connect (xml, "on_sp_border_size_value_changed",		
-			    GTK_SIGNAL_FUNC (magui_border_size_value_changed));
-    glade_xml_signal_connect (xml, "on_sp_zp_height_value_changed",		
-			    GTK_SIGNAL_FUNC (magui_zp_height_value_changed));
-    glade_xml_signal_connect (xml, "on_sp_zp_width_value_changed",		
-			    GTK_SIGNAL_FUNC (magui_zp_width_value_changed));
-    glade_xml_signal_connect (xml, "on_sp_zp_top_value_changed",		
-			    GTK_SIGNAL_FUNC (magui_zp_top_value_changed));
-    glade_xml_signal_connect (xml, "on_sp_zp_left_value_changed",		
-			    GTK_SIGNAL_FUNC (magui_zp_left_value_changed));
-    
-    glade_xml_signal_connect (xml, "on_ck_panning_toggled",	
-			    GTK_SIGNAL_FUNC (magui_panning_toggled));
-
-    glade_xml_signal_connect (xml, "on_ck_invert_toggled",	
-			    GTK_SIGNAL_FUNC (magui_invert_toggled));
-
-    glade_xml_signal_connect (xml, "on_et_smoothing_changed",	
-			    GTK_SIGNAL_FUNC (magui_smoothing_value_changed));
-
-    glade_xml_signal_connect (xml, "on_et_mouse_tracking_changed",	
-			    GTK_SIGNAL_FUNC (magui_mouse_tracking_value_changed));
-			    
-    glade_xml_signal_connect (xml, "on_sp_zoomfactor_x_value_changed",	
-			    GTK_SIGNAL_FUNC (on_change_sp1_value));
-    glade_xml_signal_connect (xml, "on_sp_zoomfactor_y_value_changed",	
-			    GTK_SIGNAL_FUNC (on_change_sp2_value));
-    glade_xml_signal_connect (xml, "on_ck_lock_factor_toggled",			
-			    GTK_SIGNAL_FUNC (magui_change_lock_factor));
-				
-    glade_xml_signal_connect (xml, "on_rb_focus_tracking_none_clicked",
-				GTK_SIGNAL_FUNC (magui_rb_focus_tracking_toggled));
-    glade_xml_signal_connect (xml, "on_rb_focus_tracking_centered_clicked",
-				GTK_SIGNAL_FUNC (magui_rb_focus_tracking_toggled));
-    glade_xml_signal_connect (xml, "on_rb_focus_tracking_auto_clicked",
-				GTK_SIGNAL_FUNC (magui_rb_focus_tracking_toggled));
 }
 
 
