@@ -216,6 +216,7 @@ static SpeakerSettings*
 spui_voice_add_modify_new_speaker_settings_get (void)
 {
     SpeakerSettings *new_settings = NULL;
+    gchar *voice_name;
     
     if (!spui_speech_voice_add_modify.w_voice_setting_add_modify)
 	return NULL;
@@ -224,13 +225,19 @@ spui_voice_add_modify_new_speaker_settings_get (void)
     new_settings->volume 		= CHECK_RANGE_OF_VALUE (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_volume)), MIN_SPEECH_VOLUME, MAX_SPEECH_VOLUME);
     new_settings->rate   		= CHECK_RANGE_OF_VALUE (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_rate)), MIN_SPEECH_RATE, MAX_SPEECH_RATE);
     new_settings->pitch  		= CHECK_RANGE_OF_VALUE (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spui_speech_voice_add_modify.sp_voice_pitch)), MIN_SPEECH_PITCH, MAX_SPEECH_PITCH);
-    new_settings->voice_name 		= g_strdup (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (spui_speech_voice_add_modify.cb_engine_voice)->entry)));
-    new_settings->voice_name_descr	= spconf_driver_list_voice_descr_name_get (new_settings->voice_name);
     new_settings->driver_name_descr	= g_strdup (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (spui_speech_voice_add_modify.cb_engine_driver)->entry)));
     new_settings->driver_name 		= g_strdup (spconf_driver_list_get_driver_name (sp_speech_driver_list,
 											new_settings->driver_name_descr));
     new_settings->gnopernicus_speaker 	= g_strdup (gtk_entry_get_text (GTK_ENTRY (spui_speech_voice_add_modify.et_gnopernicus_voice)));    
-    
+
+    voice_name 				= g_strdup (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (spui_speech_voice_add_modify.cb_engine_voice)->entry)));
+    new_settings->voice_name 		= g_strdup (spconf_driver_list_get_voice_name (
+							sp_speech_driver_list, 
+							new_settings->driver_name,
+							voice_name));
+    g_free (voice_name);  
+    new_settings->voice_name_descr	= spconf_driver_list_voice_descr_name_get (new_settings->voice_name);    
+
     return new_settings;
 }
 
@@ -241,6 +248,9 @@ spui_voice_add_modify_properties_get (void)
     GnopernicusSpeakerListType *gs_found = NULL;
     SpeakerSettings *new_setting = NULL;
     GtkTreeModel    *model = NULL;
+    gboolean 	valid;
+    gchar 	*path;
+     
 
     if (!spui_speech_voice_add_modify.w_voice_setting_add_modify ||
 	!sp_curr_speaker_settings    ||
@@ -253,10 +263,17 @@ spui_voice_add_modify_properties_get (void)
 
     ss_found = spconf_speaker_settings_list_find (sp_speakers_settings, new_setting->gnopernicus_speaker);
     gs_found = spconf_gnopernicus_speakers_find (sp_gnopernicus_speakers, new_setting->gnopernicus_speaker);
+    path     = g_strdup_printf ("%s%s%s", 
+		                CONFIG_PATH, 
+			        SPEECH_VOICE_PARAM_KEY_PATH, 
+			        new_setting->gnopernicus_speaker);
+    valid = spconf_key_is_valid (path);
+    g_free (path);
     
     if (!ss_found && !gs_found &&
 	strcmp (NONE_ELEMENT,  new_setting->gnopernicus_speaker) && 
-	strcmp (INVALID_VOICE, new_setting->gnopernicus_speaker)) 
+	strcmp (INVALID_VOICE, new_setting->gnopernicus_speaker) &&
+	valid) 
     {
 	sp_curr_speaker_settings->data = 
 		spconf_speaker_settings_copy (sp_curr_speaker_settings->data, 
@@ -269,13 +286,15 @@ spui_voice_add_modify_properties_get (void)
 	sp_speakers_settings =
 	    spconf_speaker_settings_list_remove (sp_speakers_settings,
 						     ((SpeakerSettings*)(sp_curr_speaker_settings->data))->gnopernicus_speaker);
+	sp_curr_speaker_settings = NULL;
 	sp_gnopernicus_speakers =
 	    spconf_gnopernicus_speakers_remove (sp_gnopernicus_speakers,
 						    sp_curr_gnopernicus_speaker->data);
+	sp_curr_gnopernicus_speaker = NULL;
 	gtk_list_store_remove (GTK_LIST_STORE (model), &sp_curr_iter);
 
 	gn_show_message (_("Invalid voice!"));
-	    
+
 	return FALSE;
     }
     
@@ -304,6 +323,7 @@ spui_voice_add_modify_restore_state (void)
 	    sp_speakers_settings =
 		spconf_speaker_settings_list_remove (sp_speakers_settings,
 		((SpeakerSettings*)sp_curr_speaker_settings->data)->gnopernicus_speaker);
+	    sp_curr_speaker_settings = NULL;
 	}
     }
     else
@@ -335,7 +355,10 @@ spui_voice_add_modify_speaker_values_modify (SpeakerSettings *settings)
 
     if (!spui_speech_voice_add_modify.w_voice_setting_add_modify) 
 	return FALSE;
-	
+
+    if (!sp_curr_speaker_settings)
+	return FALSE;
+
     if (strcmp (((SpeakerSettings*)sp_curr_speaker_settings->data)->gnopernicus_speaker, 
 		settings->gnopernicus_speaker))
 	return FALSE;
@@ -571,6 +594,33 @@ spui_voice_add_modify_speaker_combo_changed (GtkWidget *widget,
         spconf_speaker_settings_save (curr_setting);
 }
 
+static void
+spui_voice_add_modify_et_gnopernicus_voice_insert_text (GtkEditable *editable,
+							gchar *new_text,
+							gint new_text_length,
+							gint *position,
+							gpointer user_data)
+{
+    const gchar *rv;
+    gchar *name;
+    gchar *key;
+    
+    rv = gtk_entry_get_text (GTK_ENTRY (spui_speech_voice_add_modify.et_gnopernicus_voice));
+
+    name = g_strconcat (rv ? rv : "", new_text, NULL);
+    key = g_strdup_printf ("%s%s%s", CONFIG_PATH, SPEECH_VOICE_PARAM_KEY_PATH, name);
+   
+    if (strcmp (name, _("<none>")) && !spconf_key_is_valid (key))
+    {
+	gdk_beep ();
+	g_signal_stop_emission_by_name (editable, "insert-text");
+    }
+    
+    g_free (name);
+    g_free (key);
+}
+
+
 static void
 spui_voice_add_modify_response (GtkDialog *dialog,
 				gint       response_id,
@@ -639,6 +689,8 @@ spui_voice_add_modify_handlers_set  (GladeXML *xml)
 		      G_CALLBACK (spui_voice_add_modify_response), NULL);
     g_signal_connect (spui_speech_voice_add_modify.w_voice_setting_add_modify, "delete_event",
                       G_CALLBACK (spui_delete_emit_response_cancel), NULL);
+    g_signal_connect (spui_speech_voice_add_modify.et_gnopernicus_voice, "insert_text",			
+		      G_CALLBACK (spui_voice_add_modify_et_gnopernicus_voice_insert_text), NULL);
 
     glade_xml_signal_connect (xml,"on_combo-entry6_changed",		
 			    GTK_SIGNAL_FUNC (spui_voice_add_modify_driver_combo_changed));
@@ -1535,8 +1587,10 @@ static gboolean
 spui_voice_settings_button_add_clicked (GtkWidget *widget,
 	    				gpointer  user_data)
 {
-    GtkTreeModel     *model;
-    GtkTreeSelection *selection;
+    GtkTreeModel     	*model;
+    GtkTreeSelection 	*selection;
+    const SpeechDriver  *driver;
+    const gchar      	*default_voice_name;
 
     model 	  = gtk_tree_view_get_model 	(GTK_TREE_VIEW (spui_speech_voice.tv_voice_table));
     selection     = gtk_tree_view_get_selection (GTK_TREE_VIEW (spui_speech_voice.tv_voice_table));
@@ -1556,13 +1610,21 @@ spui_voice_settings_button_add_clicked (GtkWidget *widget,
     /* add default item in lists */
     sp_gnopernicus_speakers = 
 	spconf_gnopernicus_speakers_add (sp_gnopernicus_speakers, NONE_ELEMENT);
-    sp_speakers_settings = 
-	spconf_speaker_settings_list_add (sp_speakers_settings, NONE_ELEMENT,
-							     DEFAULT_SPEECH_ENGINE_DRIVER,
-							     DEFAULT_SPEECH_ENGINE_VOICE,
-							     DEFAULT_SPEECH_VOLUME, 
-							     DEFAULT_SPEECH_PITCH,
-							     DEFAULT_SPEECH_RATE);
+    
+    driver = spconf_driver_list_get_default_driver (sp_speech_driver_list, 
+						    DEFAULT_SPEECH_ENGINE_DRIVER);  
+    default_voice_name = spconf_voice_list_get_default_voice (driver->driver_voice_list, 
+						    DEFAULT_SPEECH_ENGINE_VOICE);
+    if (driver)
+	sp_speakers_settings = 
+	    spconf_speaker_settings_list_add (sp_speakers_settings, 
+					      NONE_ELEMENT,
+					      driver->driver_name,
+					      default_voice_name, 
+					      DEFAULT_SPEECH_VOLUME, 
+					      DEFAULT_SPEECH_PITCH,
+					      DEFAULT_SPEECH_RATE);
+    
     /* find item in lists */				    
     sp_curr_speaker_settings    = g_slist_last (sp_speakers_settings);
     sp_curr_gnopernicus_speaker = g_slist_last (sp_gnopernicus_speakers);
@@ -1667,10 +1729,12 @@ spui_voice_settings_button_remove_clicked (GtkWidget *widget,
     sp_gnopernicus_speakers =
 	spconf_gnopernicus_speakers_remove (sp_gnopernicus_speakers,
 					    gnoper_speaker);
+    sp_curr_gnopernicus_speaker = NULL;
     /* remove from sp_speakers_settings list the elem */	    
     sp_speakers_settings =
 	spconf_speaker_settings_list_remove (sp_speakers_settings,
 					     gnoper_speaker);
+    sp_curr_speaker_settings = NULL;
 
     /* remove from list store the elem */					  
     gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
@@ -1701,8 +1765,10 @@ spui_voice_settings_free_lists (void)
 	    spconf_speaker_settings_list_free (sp_speakers_settings_backup);
     sp_gnopernicus_speakers =
 	    spconf_gnopernicus_speakers_free (sp_gnopernicus_speakers);
+    sp_curr_gnopernicus_speaker = NULL;
     sp_speakers_settings  =
 	    spconf_speaker_settings_list_free (sp_speakers_settings);
+    sp_curr_speaker_settings = NULL;
     sp_speech_driver_list =
 	    spconf_driver_list_free (sp_speech_driver_list);
 }
