@@ -118,6 +118,7 @@ srs_check_for_callbacks (gpointer key,
 gboolean
 srs_voice_update_from_info (SRSVoiceInfo *voice)
 {
+    gboolean rv = FALSE;
     SRSVoice *found;
 
     sru_assert (voice && voice->id);
@@ -128,13 +129,24 @@ srs_voice_update_from_info (SRSVoiceInfo *voice)
 */
     found = srs_voice_find (voice->id);
     if (found)
-    	srs_gs_speaker_update (found->speaker, voice);
+    {
+    	if (!srs_gs_speaker_update (found->speaker, voice))
+	{
+	    g_hash_table_remove (srs_voices, voice->id);
+	    rv = FALSE;
+	}
+    }
     else
     {
-	found = srs_voice_new ();
-	found->id = g_strdup (voice->id);
-	found->speaker = srs_gs_speaker_new (voice);
-	srs_voice_add (found);
+	SRSGSSpeaker *speaker = srs_gs_speaker_new (voice);
+	if (speaker)
+	{
+	    found = srs_voice_new ();
+	    found->id = g_strdup (voice->id);
+	    found->speaker = speaker;
+	    srs_voice_add (found);
+	    rv = TRUE;
+	}
     }
 
 #ifdef SRS_NO_MARKERS_SUPPORTED
@@ -142,7 +154,7 @@ srs_voice_update_from_info (SRSVoiceInfo *voice)
     g_hash_table_foreach (srs_voices, srs_check_for_callbacks, NULL);
 #endif
 
-    return TRUE;
+    return rv;
 }
 
 SRSTextOut*
