@@ -48,6 +48,8 @@
 static gboolean src_speech_initialized     = FALSE;
 
 static GHashTable *src_dictionary_hash 	= NULL;
+static guint      speech_timeout_id;
+static gboolean   src_speech_restored = FALSE;
 
 typedef struct 
 {
@@ -90,6 +92,7 @@ typedef struct _SRCSOut
 static GPtrArray     	*src_voice_params = NULL;
 SRCSpeech 	 	*src_speech = NULL;
 static SRCVoices 	*src_voices = NULL;
+static GPtrArray	*src_created_voices = NULL;
 
 static gboolean src_speech_idle = TRUE;
 static GSList *srcs_outs = NULL;
@@ -191,14 +194,13 @@ src_speech_valid_voice (gchar *voice)
     gint i;
 
     sru_assert (src_speech_initialized);
-    sru_assert (src_voices->voices);
     sru_assert (voice);
 
-    for (i = 0; src_voices->voices[i]; i++)
+    for (i = 0; i < src_created_voices->len; i++)
     {
-	if (strcmp (voice, src_voices->voices[i]) == 0)
+	if (strcmp (voice, g_ptr_array_index (src_created_voices, i)) == 0)
 	    return TRUE;
-    }    
+    }
     return FALSE;
 }
 
@@ -477,7 +479,7 @@ src_speech_send (gchar *spcoutput)
     if (g_utf8_validate (spcoutput, -1, NULL))
 	srs_output (spcoutput, strlen(spcoutput)); 
     else
-	    sru_warning ("speech output: invalid UTF-8 received");
+        sru_warning ("speech output: invalid UTF-8 received");
     rv = TRUE;
 
     sru_debug_log ("out", "send to speech:%s", spcoutput);
@@ -1524,6 +1526,8 @@ src_timeout_start_speech (gpointer data)
 {
     gboolean use_speech = TRUE;
     SET_SRCORE_CONFIG_DATA (SRCORE_SPEECH_ACTIVE, CFGT_BOOL, &use_speech);
+    speech_timeout_id = 0;
+    src_speech_restored = TRUE;
     return FALSE;    
 }
 
@@ -1534,12 +1538,13 @@ src_restart_speech ()
     g_printerr ("\nRestarting speech.\n");
     gboolean use_speech = FALSE;
     SET_SRCORE_CONFIG_DATA (SRCORE_SPEECH_ACTIVE, CFGT_BOOL, &use_speech);
-    g_timeout_add (SRC_SPEECH_RESTART_TIMEOUT, src_timeout_start_speech, NULL);
+    speech_timeout_id = g_timeout_add (SRC_SPEECH_RESTART_TIMEOUT, src_timeout_start_speech, NULL);
 }
 
 gboolean
 src_speech_init ()
 {
+    gboolean terminate = FALSE;
     sru_assert (!src_speech_initialized);
 
     SRU_DEBUG_ADD_MODULE_AND_SCOPES;
@@ -1547,6 +1552,7 @@ src_speech_init ()
     src_speech_idle = TRUE;
     srcs_outs = NULL;
     last_out = NULL;
+    src_created_voices = g_ptr_array_new ();
     src_voice_params = g_ptr_array_new ();
     
     src_voices = src_speech_src_voices_new ();
@@ -1555,7 +1561,7 @@ src_speech_init ()
     src_speech_set_default_values (src_speech);
     
     srcs_in_init ();
-    src_speech_initialized = srs_init (srcs_in_parse_input, src_restart_speech);
+    terminate = src_speech_initialized = srs_init (srcs_in_parse_input, src_restart_speech);
 #ifdef SRS_NO_MARKERS_SUPPORTED
     src_speech_callback = TRUE;
     src_speech_unspoken = NULL;
@@ -1572,12 +1578,28 @@ src_speech_init ()
     {
 	src_speech_initialized = src_speech_init_default_voice () &&
 				 src_speech_voices_init ();
+	if (src_speech_initialized)
+	{	
+	    gint i;
+	    src_speech_initialized = FALSE;
+	    for (i = 0; i < src_created_voices->len; i++)
+	    {
+		if (strcmp ("default", g_ptr_array_index (src_created_voices, i)) == 0)
+		{
+		    src_speech_initialized = TRUE;
+		    break;
+		}
+	    }
+	}
     }
     else
     {
 	src_speech_initialized = FALSE;
     }
 
+    if (!src_speech_initialized && terminate)
+	srs_terminate ();
+
     if (src_speech_initialized)
 	src_dictionary_init ();
 
@@ -1594,6 +1616,8 @@ src_speech_init ()
     if (src_speech_initialized)
     {
     	sru_message (_("speech initialization succeded"));
+	if (src_speech_restored)
+	    src_speech_say_message (("Speech restored")); /*TO BE TRANSLATED*/
     }
     else
     {
@@ -1626,6 +1650,12 @@ src_speech_terminate ()
     g_strfreev (src_voices->voices);
     g_strfreev (src_voices->engine_voices);
     g_strfreev (src_voices->engine_drivers);
+    g_ptr_array_add (src_created_voices, NULL);
+    g_strfreev ((gchar**)g_ptr_array_free (src_created_voices, TRUE));
+    
+    gboolean use_speech = TRUE;
+    if (speech_timeout_id == 0)
+        SET_SRCORE_CONFIG_DATA (SRCORE_SPEECH_ACTIVE, CFGT_BOOL, &use_speech);
 }
 
 #define src_speech_is_separator(x) (( x == '.' || x == ';' || x == '?' || x == ',' || x == '!' ) ? TRUE : FALSE)
@@ -2212,7 +2242,9 @@ src_speech_add_created_voice (gchar *name
 #endif
 			    )
 {
-    
+    g_assert (name);
+
+    g_ptr_array_add (src_created_voices, g_strdup (name));
 #ifdef SRS_NO_MARKERS_SUPPORTED
     if (src_speech_callback)
     {
