@@ -195,12 +195,14 @@ static GQueue			*srl_event_queue	= NULL;
 static AccessibleEventListener 	*srl_event_listeners[G_N_ELEMENTS (srl_events_type_name)];
 static Accessible		*srl_last_focus		= NULL;
 static Accessible		*srl_last_focus2	= NULL;
+static Accessible		*srl_last_at_spi_focus	= NULL;
 static Accessible		*srl_watched_acc	= NULL;
 static Accessible 		*srl_last_table 	= NULL;
 static Accessible 		*srl_last_context 	= NULL;
 static Accessible		*srl_last_create	= NULL;
 /*FIXME:next varaible should be in SRObject.c file */
 Accessible 			*srl_last_edit		= NULL;
+static gint 			srl_last_row = -1;
 
 extern gboolean sro_set_difference (SRObject *obj, gchar *difference);
 extern gboolean sro_set_name (SRObject *obj, gchar *name);
@@ -592,6 +594,92 @@ srl_acc_has_state (Accessible *acc,
     return rv;
 }
 
+static Accessible*
+srl_get_focused_cell (Accessible *acc_table)
+{
+    Accessible *rv = NULL;
+    AccessibleTable *table;
+    AccessibleComponent *comp;
+    gint rows, rowe, cols, cole;
+
+    srl_assert (acc_table);
+
+    table = Accessible_getTable (acc_table);
+    comp = Accessible_getComponent (acc_table);
+
+    rows = rowe = cols = cole = -1;
+    if (table && comp)
+    {
+	long int x, y, w, h;
+	gint index;
+	Accessible *corner;
+
+	AccessibleComponent_getExtents  (comp, &x, &y, &w, &h,
+						    SPI_COORD_TYPE_WINDOW);
+	/* get the uper-left corner */
+    	corner = AccessibleComponent_getAccessibleAtPoint (comp, x + 1, y + 1,
+					    	    SPI_COORD_TYPE_WINDOW);
+	if (corner)
+	{
+	    index = Accessible_getIndexInParent (corner);
+	    rows = AccessibleTable_getRowAtIndex (table, index);
+	    cols = AccessibleTable_getColumnAtIndex (table, index);
+	    Accessible_unref (corner);
+	}
+	else
+	    rows = cols = 0;
+	
+	/* get the bottom-left corner */
+    	corner = AccessibleComponent_getAccessibleAtPoint (comp, x + 1, y + h - 1,
+					    	    SPI_COORD_TYPE_WINDOW);
+	if (corner)
+	{
+	    index = Accessible_getIndexInParent (corner);
+	    rowe = AccessibleTable_getRowAtIndex (table, index);
+	    Accessible_unref (corner);
+	}
+	else
+	    rowe = AccessibleTable_getNRows (table);
+
+	/* get the upper-right corner */
+    	corner = AccessibleComponent_getAccessibleAtPoint (comp, x + w - 1, y + 1,
+					    	    SPI_COORD_TYPE_WINDOW);
+	if (corner)
+	{
+	    index = Accessible_getIndexInParent (corner);
+	    cole = AccessibleTable_getColumnAtIndex (table, index);
+	    Accessible_unref (corner);
+	}
+	else
+	    cole = AccessibleTable_getNColumns (table);
+	
+    }
+
+    if (rows != -1 && cols != -1)
+    {
+	gint i, j;
+	for (i = rows; !rv && i <= rowe; i++)
+	    for (j = cols; !rv && j <= cole; j++)
+	    {
+		Accessible *cell = AccessibleTable_getAccessibleAt (table, i, j);
+		if (cell)
+		{
+		    if (srl_acc_has_state (cell, SPI_STATE_FOCUSED))
+			rv = cell;
+		    else
+		        Accessible_unref (cell);
+		}
+	    }
+    }
+
+    if (table)
+	AccessibleTable_unref (table);
+    if (comp)
+	AccessibleComponent_unref (comp);
+
+    return rv;
+}
+
 static gboolean
 srle_acc_has_state (SRLEvent *event,
 		    AccessibleState state)
@@ -669,6 +757,8 @@ srle_set_acc (SRLEvent *event)
 			    Accessible_unref (child);
 		    }
 		}
+		if (!event->acc)
+		    event->acc = srl_get_focused_cell (event->acc_ev->source);
 	    }
 	    
 	    AccessibleSelection_unref (selection);
@@ -897,7 +987,6 @@ srl_set_last_table (Accessible *acc)
 static gboolean
 srl_table_same_line (Accessible *acc)
 {
-    static gint last_row = -1;
     Accessible *parent;
     gboolean rv = FALSE;
 
@@ -911,9 +1000,9 @@ srl_table_same_line (Accessible *acc)
 	{
 	    gint row = AccessibleTable_getRowAtIndex (table, 
 				    Accessible_getIndexInParent (acc));
-	    if (row == last_row && parent == srl_last_table)
+	    if (row == srl_last_row && parent == srl_last_table)
 	        rv = TRUE;
-	    last_row = row;
+	    srl_last_row = row;
 	    AccessibleTable_unref (table);
 	}
 	Accessible_unref (parent);
@@ -961,6 +1050,9 @@ srl_notify_clients_obj (SRLEvent *event,
 	SRObjectRoles role;
 	sro_get_role (obj, &role, SR_INDEX_CONTAINER);
 	
+	if (role == SR_ROLE_TABLE_COLUMNS_HEADER)
+	    srl_last_row = -1;
+
 	if ((role == SR_ROLE_TABLE_LINE || role == SR_ROLE_TABLE_COLUMNS_HEADER) &&
 	    srle_has_type (event, SRL_EVENT_FOCUS))
 	{
@@ -985,11 +1077,11 @@ srl_notify_clients_obj (SRLEvent *event,
 		    sre_release_reference (pev);
 		}
 	    }
-	    else if (srle_has_type (event, SRL_EVENT_FOCUS))
-		srl_set_last_table (NULL);
 	    if (pacc)
 		Accessible_unref (pacc);
 	}
+	else if (srle_has_type (event, SRL_EVENT_FOCUS))
+	    srl_set_last_table (NULL);
     }
 
     if (obj)
@@ -1248,11 +1340,12 @@ srle_is_for_focused_ancestor_acc (SRLEvent *event)
     srl_assert (event);
 
     acc = event->acc_ev->source;
+
     Accessible_ref (acc);
     while (acc)
     {
 	Accessible *tmp;
-	rv = srl_acc_has_state (acc, SPI_STATE_FOCUSED);
+	rv = acc == srl_last_at_spi_focus;
 	if (rv)
 	    break;
 	tmp = acc;
@@ -1764,6 +1857,7 @@ srl_selection_event_is_reported (SRLEvent *event)
 
 
 static SRLLastInfo last_info_focus, last_info_watched;
+static gboolean srl_set_last_focus (Accessible *acc);
 
 static gboolean
 srl_event_is_reported (SRLEvent *event)
@@ -1810,12 +1904,16 @@ srl_event_is_reported (SRLEvent *event)
 	rv = TRUE;
     else if (srle_has_type (event, SRL_EVENT_FOCUS2))
 	rv = TRUE;
+    else if (srle_has_type (event, SRL_EVENT_STATE_EXPANDED))
+    {
+	rv = srle_is_for_focused_ancestor_acc (event);
+	if (rv)
+	    srl_set_last_focus ((Accessible*) srle_get_acc (event));
+    }
     else if (srle_is_for_focused_acc (event) ||
 	     srle_is_for_watched_acc (event))
     {
-	if (srle_has_type (event, SRL_EVENT_STATE_EXPANDED)) 
-	    rv = srle_acc_has_role (event, SPI_ROLE_TABLE_CELL);
-	else if (srle_has_type (event, SRL_EVENT_STATE_CHECKED))
+	if (srle_has_type (event, SRL_EVENT_STATE_CHECKED))
 	{
 	    if (srle_acc_has_role (event, SPI_ROLE_RADIO_BUTTON))
 		rv = !last_info->checked && srle_acc_has_state (event, SPI_STATE_CHECKED);
@@ -1843,6 +1941,8 @@ srl_event_is_reported (SRLEvent *event)
 		 srle_acc_has_role (event, SPI_ROLE_SLIDER);
 	else if (srle_has_type (event, SRL_EVENT_VISIBLE_DATA_CHANGED))
 	    rv = TRUE;
+	else if (srle_has_type (event, SRL_EVENT_STATE_SELECTED))
+	    rv = srl_last_table != NULL; /* selection changed while in a table */
     }
 
     if (srle_has_type (event, SRL_EVENT_WINDOW_DEACTIVATE))
@@ -1929,6 +2029,18 @@ srl_event_is_reported (SRLEvent *event)
     return rv;
 }
 
+static gboolean
+srl_set_last_at_spi_focus (Accessible *acc)
+{
+    if (srl_last_at_spi_focus)
+	Accessible_unref (srl_last_at_spi_focus);
+    srl_last_at_spi_focus = acc;
+    if (srl_last_at_spi_focus)
+	Accessible_ref (srl_last_at_spi_focus);
+    return TRUE;
+}
+
+
 static gboolean
 srl_set_last_focus (Accessible *acc)
 {
@@ -1960,6 +2072,9 @@ srl_process_event (SRLEvent *event)
 
     srl_assert (event);
 
+    if (srle_has_type (event, SRL_EVENT_FOCUS))
+	srl_set_last_at_spi_focus ((Accessible*)srle_get_acc (event));
+
     srl_timing_process_start ((gpointer) event->acc_ev);
     srle_set_acc (event);
     srle_change_type (event);
@@ -2053,6 +2168,7 @@ srl_init ()
 	srl_last_events[i] = NULL;
     srl_last_focus	= NULL;
     srl_last_focus2    	= NULL;
+    srl_last_at_spi_focus= NULL;
     srl_last_edit	= NULL;
     srl_idle_need	= FALSE;
     srl_idle_installed	= FALSE;
@@ -2060,7 +2176,8 @@ srl_init ()
     srl_last_table	= NULL;
     srl_last_context 	= NULL;
     srl_last_create 	= NULL;
-    
+    srl_last_row 	= -1;
+
     srl_log_init ();
     srl_timing_init ();
 
@@ -2118,6 +2235,8 @@ srl_terminate ()
 	Accessible_unref (srl_last_focus);
     if (srl_last_focus2)
 	Accessible_unref (srl_last_focus2);	
+    if (srl_last_at_spi_focus)
+	Accessible_unref (srl_last_at_spi_focus);
     if (srl_last_edit)
         Accessible_unref (srl_last_edit);
     if (srl_watched_acc)
